==> open-xchange-server_6.14.0.0.orig.tar.gz: open-xchange-server-6.14.0.0/src/com/openexchange/groupware/update/exception/Classes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.update.exception;

import com.openexchange.groupware.update.SchemaStore;
import com.openexchange.groupware.update.SchemaStoreImpl;
import com.openexchange.groupware.update.UpdateTask;
import com.openexchange.groupware.update.Updater;
import com.openexchange.groupware.update.UpdaterImpl;
import com.openexchange.groupware.update.tasks.NewAdminExtensionsUpdateTask;
import com.openexchange.groupware.update.tasks.TaskReminderFolderZero;

/**
 * Class identifier for component update exceptions.
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 */
public final class Classes {

    /**
     * {@link SchemaStoreImpl}.
     */
    public static final int SCHEMA_STORE_IMPL = 1;

    /**
     * {@link SchemaExceptionFactory}.
     */
    public static final int SCHEMA_EXCEPTION_FACTORY = 2;

    /**
     * {@link SchemaStore}.
     */
    public static final int SCHEMA_STORE = 3;

    /**
     * {@link UpdateExceptionFactory}.
     */
    public static final int UPDATE_EXCEPTION_FACTORY = 4;

    /**
     * {@link Updater}.
     */
    public static final int UPDATER = 5;
    
    /**
     * {@link UpdaterImpl}.
     */
    public static final int UPDATER_IMPL = 6;
    
    /**
     * {@link UpdateTask}.
     */
    public static final int UPDATE_TASK = 7;

    /**
     * {@link TaskReminderFolderZero}
     */
    public static final int TASK_REMINDER_FOLDER_ZERO = 8;

    /**
     * {@link NewAdminExtensionsUpdateTask}
     */
    public static final int TASK_NEW_ADMIN_EXTENSIONS = 9;

    /**
     * Prevent instantiation
     */
    private Classes() {
        super();
    }
}

==> open-xchange-server_6.18.0.0.orig.tar.gz: open-xchange-server-6.18.0.0/src/com/openexchange/groupware/update/exception/Classes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.groupware.update.exception;

import com.openexchange.groupware.update.UpdateTask;
import com.openexchange.groupware.update.tasks.NewAdminExtensionsUpdateTask;
import com.openexchange.groupware.update.tasks.TaskReminderFolderZero;

/**
 * Class identifier for component update exceptions.
 * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
 * @deprecated remove this.
 */
@Deprecated
public final class Classes {

    /**
     * {@link UpdateExceptionFactory}.
     */
    public static final int UPDATE_EXCEPTION_FACTORY = 4;
    
    /**
     * {@link UpdateTask}.
     */
    public static final int UPDATE_TASK = 7;

    /**
     * {@link TaskReminderFolderZero}
     */
    public static final int TASK_REMINDER_FOLDER_ZERO = 8;

    /**
     * {@link NewAdminExtensionsUpdateTask}
     */
    public static final int TASK_NEW_ADMIN_EXTENSIONS = 9;

    /**
     * Prevent instantiation
     */
    private Classes() {
        super();
    }
}
